CREATE TABLE Diagram (AnnotationId integer NOT NULL, Project integer NOT NULL, ParentModel integer, Id varchar(255) NOT NULL, Name varchar(255), Type varchar(255) NOT NULL, Documentation clob(10485760), Width integer NOT NULL, Height integer NOT NULL, PreviewImageXOffset integer, PreviewImageYOffset integer, PreviewImageZoomRatio numeric(3, 2), ImageWidth integer, ImageHeight integer, PreviewImageWidth integer, PreviewImageHeight integer, TrimmedTop integer, TrimmedLeft integer, PRIMARY KEY (AnnotationId));
CREATE TABLE Model (AnnotationId integer NOT NULL, Project integer NOT NULL, ParentModel integer, Id varchar(255) NOT NULL, ModelType varchar(255) NOT NULL, Name varchar(255), Documentation clob(10485760), PRIMARY KEY (AnnotationId));
CREATE TABLE FlowOfEvent (AnnotationId integer NOT NULL, UseCase integer NOT NULL, FlowOfEventAIndex integer NOT NULL, TestingProcedureAIndex integer NOT NULL, TestingProcedureId varchar(255), TestingProcedureName varchar(255), CombinedContent clob(10485760), ExtensionCombinedContent clob(10485760), FlowOfEventId varchar(255) NOT NULL, FlowOfEventName varchar(255), PRIMARY KEY (AnnotationId));
CREATE TABLE BPProcedure (AnnotationId integer NOT NULL, Model integer NOT NULL, AIndex integer NOT NULL, Id varchar(255) NOT NULL, Name varchar(255), CombinedContent clob(10485760), PRIMARY KEY (AnnotationId));
CREATE TABLE UseCase (AnnotationId integer NOT NULL, Model integer NOT NULL, Rank varchar(255), Justification varchar(255), BusinessModel smallint, UseCaseID varchar(255) NOT NULL, TestingSetup varchar(255), TestingConfig varchar(255), PRIMARY KEY (AnnotationId));
CREATE TABLE Annotation (AnnotationId integer NOT NULL, Type varchar(255) NOT NULL, Color integer NOT NULL, X integer NOT NULL, Y integer NOT NULL, Width integer NOT NULL, Height integer NOT NULL, CalloutX integer, CalloutY integer, CalloutWidth integer, CalloutHeight integer, Author varchar(255) NOT NULL, Time timestamp NOT NULL, Text varchar(32672), HighlightText varchar(32672), TargetCombinedModel clob(10485760), ShowCallout smallint NOT NULL, TargetModel integer, TargetElement integer, TargetCombinedModelId varchar(255), TargetCombinedModelStartIndex integer, TargetCombinedModelEndIndex integer, TargetDiagram integer NOT NULL, Modified smallint NOT NULL, TargetItemId varchar(255), CellType varchar(255), PRIMARY KEY (AnnotationId));
CREATE TABLE Element (AnnotationId integer NOT NULL, Diagram integer NOT NULL, Model integer, Id varchar(255) NOT NULL, ElementType varchar(255) NOT NULL, Zorder integer NOT NULL, X integer NOT NULL, Y integer NOT NULL, Width integer NOT NULL, Height integer NOT NULL, FromElement integer, ToElement integer, PRIMARY KEY (AnnotationId));
CREATE TABLE AnnotationPenPoint (AnnotationId integer NOT NULL, Annotation integer NOT NULL, AIndex integer NOT NULL, X integer NOT NULL, Y integer NOT NULL, PRIMARY KEY (AnnotationId));
CREATE TABLE Project (AnnotationId integer NOT NULL, Id varchar(255) NOT NULL, LocalFolder varchar(255) NOT NULL, Name varchar(255), Documentation clob(10485760), ServerConnection integer, ServerId integer, Owner varchar(255), OwnerEmail varchar(255), StartDate timestamp, Finished smallint, FinishedDate timestamp, Expired smallint, ExpiryDate timestamp, Completed smallint, CompleteDate timestamp, PreviewDiagramId integer, PRIMARY KEY (AnnotationId));
CREATE TABLE ConnectorPoint (AnnotationId integer NOT NULL, Element integer NOT NULL, AIndex integer NOT NULL, X integer NOT NULL, Y integer NOT NULL, PRIMARY KEY (AnnotationId));
CREATE TABLE TestPlan (AnnotationId integer NOT NULL, Model integer NOT NULL, CombinedContent clob(10485760), PRIMARY KEY (AnnotationId));
CREATE TABLE UseCase_Requirement (AnnotationId integer NOT NULL, UseCase integer NOT NULL, Requirement integer NOT NULL, AIndex integer NOT NULL, PRIMARY KEY (AnnotationId));
CREATE TABLE UseCase_PrimaryActor (AnnotationId integer NOT NULL, UseCase integer NOT NULL, PrimaryActor integer NOT NULL, AIndex integer NOT NULL, PRIMARY KEY (AnnotationId));
CREATE TABLE UseCase_SupportingActor (AnnotationId integer NOT NULL, UseCase integer NOT NULL, SupportingActor integer NOT NULL, AIndex integer NOT NULL, PRIMARY KEY (AnnotationId));
CREATE TABLE Element_Relationship (AnnotationId integer NOT NULL, Element integer NOT NULL, AIndex integer NOT NULL, RelationshipElement integer NOT NULL, IsFrom smallint NOT NULL, PRIMARY KEY (AnnotationId));
CREATE TABLE Model_Reference (AnnotationId integer NOT NULL, Model integer NOT NULL, AIndex integer NOT NULL, ReferenceHyperlink varchar(255), ReferenceDiagram integer, ReferenceModel integer, ReferenceElement integer, Name varchar(255), Documentation clob(10485760), PRIMARY KEY (AnnotationId));
CREATE TABLE UniqueIDTable (LastId integer NOT NULL, Type varchar(255) NOT NULL, PRIMARY KEY (LastId, Type));
CREATE TABLE ServerConnection (AnnotationId integer NOT NULL, Name varchar(255) NOT NULL, Host varchar(255) NOT NULL, Port integer NOT NULL, Url varchar(255) NOT NULL, Username varchar(255) NOT NULL, Password varchar(255) NOT NULL, WebApplicationName varchar(255) NOT NULL, Deleted smallint, PRIMARY KEY (AnnotationId));
CREATE TABLE Proxy (AnnotationId integer NOT NULL GENERATED ALWAYS AS IDENTITY, UseProxy smallint NOT NULL, Host varchar(255), Port integer, Username varchar(255), Password varchar(255), PRIMARY KEY (AnnotationId));
CREATE TABLE Preference (AnnotationId integer NOT NULL, ShowFrame smallint, FrameX integer, FrameY integer, FrameWidth integer, FrameHeight integer, FileSystemSelectedTab integer, LastServerId integer, PRIMARY KEY (AnnotationId));
CREATE TABLE UseCase_Detail (AnnotationId integer NOT NULL, UseCase integer NOT NULL, AIndex integer, Name varchar(255), CombinedContent clob(10485760), PRIMARY KEY (AnnotationId));
ALTER TABLE UseCase ADD CONSTRAINT FKUseCase261620 FOREIGN KEY (Model) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Diagram ADD CONSTRAINT FKDiagram617264 FOREIGN KEY (Project) REFERENCES Project (AnnotationId) ON DELETE Cascade;
ALTER TABLE Element ADD CONSTRAINT FKElement953840 FOREIGN KEY (Diagram) REFERENCES Diagram (AnnotationId) ON DELETE Cascade;
ALTER TABLE AnnotationPenPoint ADD CONSTRAINT FKAnnotation574578 FOREIGN KEY (Annotation) REFERENCES Annotation (AnnotationId) ON DELETE Cascade;
ALTER TABLE Model ADD CONSTRAINT FKModel663360 FOREIGN KEY (Project) REFERENCES Project (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_SupportingActor ADD CONSTRAINT FKUseCase_Su972980 FOREIGN KEY (UseCase) REFERENCES UseCase (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_SupportingActor ADD CONSTRAINT FKUseCase_Su389186 FOREIGN KEY (SupportingActor) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_PrimaryActor ADD CONSTRAINT FKUseCase_Pr414054 FOREIGN KEY (UseCase) REFERENCES UseCase (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_PrimaryActor ADD CONSTRAINT FKUseCase_Pr730190 FOREIGN KEY (PrimaryActor) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_Requirement ADD CONSTRAINT FKUseCase_Re37582 FOREIGN KEY (UseCase) REFERENCES UseCase (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_Requirement ADD CONSTRAINT FKUseCase_Re434322 FOREIGN KEY (Requirement) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE FlowOfEvent ADD CONSTRAINT FKFlowOfEven91495 FOREIGN KEY (UseCase) REFERENCES UseCase (AnnotationId) ON DELETE Cascade;
ALTER TABLE BPProcedure ADD CONSTRAINT FKBPProcedur17323 FOREIGN KEY (Model) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE TestPlan ADD CONSTRAINT FKTestPlan121070 FOREIGN KEY (Model) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Model_Reference ADD CONSTRAINT FKModel_Refe680278 FOREIGN KEY (Model) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Model_Reference ADD CONSTRAINT FKModel_Refe513288 FOREIGN KEY (ReferenceDiagram) REFERENCES Diagram (AnnotationId) ON DELETE Cascade;
ALTER TABLE Model_Reference ADD CONSTRAINT FKModel_Refe383137 FOREIGN KEY (ReferenceModel) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Element ADD CONSTRAINT FKElement953966 FOREIGN KEY (Model) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Model_Reference ADD CONSTRAINT FKModel_Refe992427 FOREIGN KEY (ReferenceElement) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE ConnectorPoint ADD CONSTRAINT FKConnectorP980693 FOREIGN KEY (Element) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE Diagram ADD CONSTRAINT FKDiagram484604 FOREIGN KEY (ParentModel) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Element_Relationship ADD CONSTRAINT FKElement_Re848083 FOREIGN KEY (Element) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE Annotation ADD CONSTRAINT FKAnnotation557390 FOREIGN KEY (TargetElement) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE Annotation ADD CONSTRAINT FKAnnotation558921 FOREIGN KEY (TargetModel) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Model ADD CONSTRAINT FKModel530700 FOREIGN KEY (ParentModel) REFERENCES Model (AnnotationId) ON DELETE Cascade;
ALTER TABLE Element_Relationship ADD CONSTRAINT FKElement_Re260607 FOREIGN KEY (RelationshipElement) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE Annotation ADD CONSTRAINT FKAnnotation908483 FOREIGN KEY (TargetDiagram) REFERENCES Diagram (AnnotationId) ON DELETE Cascade;
ALTER TABLE Element ADD CONSTRAINT FKElement88313 FOREIGN KEY (FromElement) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE Element ADD CONSTRAINT FKElement350115 FOREIGN KEY (ToElement) REFERENCES Element (AnnotationId) ON DELETE Cascade;
ALTER TABLE Project ADD CONSTRAINT FKProject429930 FOREIGN KEY (ServerConnection) REFERENCES ServerConnection (AnnotationId) ON DELETE Cascade;
ALTER TABLE Project ADD CONSTRAINT FKProject151170 FOREIGN KEY (PreviewDiagramId) REFERENCES Diagram (AnnotationId) ON DELETE Cascade;
ALTER TABLE UseCase_Detail ADD CONSTRAINT FKUseCase_De251539 FOREIGN KEY (UseCase) REFERENCES UseCase (AnnotationId) ON DELETE Cascade;
